Stan Math Library: stan/math/prim/scal/fun/digamma.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

digamma.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_FUN_DIGAMMA_HPP
2 #define STAN_MATH_PRIM_SCAL_FUN_DIGAMMA_HPP
3
4 #include <boost/math/special_functions/digamma.hpp>
5
6 namespace stan {
7
8 namespace math {
9
39 double digamma(double x) {
40 return boost::math::digamma(x);
41 }
42
43 }
44 }
45
46 #endif
stan
Definition: log_sum_exp.hpp:8
stan::math::digamma
var digamma(const stan::math::var &a)
Definition: digamma.hpp:24
stan::math::digamma
fvar< T > digamma(const fvar< T > &x)
Definition: digamma.hpp:16

[ Stan Home Page ] © 2011–2016, Stan Development Team.